@@ -3,23 +3,26 @@ count step
 """
 
 import os
-import sys
 import random
+import subprocess
+import sys
+import unittest
 from collections import defaultdict
 from itertools import groupby
-import subprocess
 
 import numpy as np
 import pandas as pd
+import pysam
 from scipy.io import mmwrite
 from scipy.sparse import coo_matrix
-import pysam
 
 import celescope.tools.utils as utils
-from celescope.tools.cellranger3.cell_calling_3 import cell_calling_3
-from celescope.tools.__init__ import MATRIX_FILE_NAME, FEATURE_FILE_NAME, BARCODE_FILE_NAME
+from celescope.tools.__init__ import (BARCODE_FILE_NAME, FEATURE_FILE_NAME,
+                                      MATRIX_FILE_NAME)
 from celescope.tools.cellranger3 import get_plot_elements
+from celescope.tools.cellranger3.cell_calling_3 import cell_calling_3
 from celescope.tools.step import Step, s_common
+from celescope.rna.mkref import parse_genomeDir_rna
 
 TOOLS_DIR = os.path.dirname(__file__)
 random.seed(0)
@@ -27,17 +30,59 @@ np.random.seed(0)
 
 
 class Count(Step):
+    """
+    Features
+    - Cell-calling: Distinguish cell barcodes from background barcodes. 
+
+    - Generate expression matrix.
+
+    Output
+    - `{sample}_all_matrix` The expression matrix of all detected barcodes. 
+        Can be read in by calling the `Seurat::Read10X` function.
+
+    - `{sample}_matrix_10X` The expression matrix of the barcode that is identified to be the cell. 
+    Can be read in by calling the `Seurat::Read10X` function.
+
+    - `{sample}_matrix.tsv.gz` The expression matrix of the barcode that is identified to be the cell, separated by tabs. 
+    CeleScope >=1.2.0 does not output this file.
+
+    - `{sample}_count_detail.txt.gz` 4 columns: 
+        - barcode  
+        - gene ID  
+        - UMI count  
+        - read_count  
+
+    - `{sample}_counts.txt` 6 columns:
+        - Barcode: barcode sequence
+        - readcount: read count of each barcode
+        - UMI2: UMI count (with reads per UMI >= 2) for each barcode
+        - UMI: UMI count for each barcode
+        - geneID: gene count for each barcode
+        - mark: cell barcode or backgound barcode.
+
+            `CB` cell  
+            `UB` background  
+
+    - `{sample}_downsample.txt` 3 columns：
+        - percent: percentage of sampled reads
+        - median_geneNum: median gene number per cell
+        - saturation: sequencing saturation
+
+    - `barcode_filter_magnitude.pdf` Barcode-UMI plot.
+
+
+    """
+
     def __init__(self, args, step):
         Step.__init__(self, args, step)
         self.force_cell_num = args.force_cell_num
         self.cell_calling_method = args.cell_calling_method
         self.expected_cell_num = int(args.expected_cell_num)
         self.bam = args.bam
-        if args.genomeDir and args.genomeDir != "None":
-            _refFlat, self.gtf_file, _ = utils.glob_genomeDir(args.genomeDir)
-        else:
-            self.gtf_file = args.gtf
-        self.id_name = utils.gene_convert(self.gtf_file)
+
+        # set
+        self.gtf_file = parse_genomeDir_rna(args.genomeDir)['gtf']
+        self.id_name = utils.get_id_name_dict(self.gtf_file)
 
         # output files
         self.count_detail_file = f'{self.outdir}/{self.sample}_count_detail.txt'
@@ -137,12 +182,13 @@ class Count(Step):
     def bam2table(self):
         """
         bam to detail table
+        must be used on name_sorted bam
         """
         samfile = pysam.AlignmentFile(self.bam, "rb")
         with open(self.count_detail_file, 'wt') as fh1:
             fh1.write('\t'.join(['Barcode', 'geneID', 'UMI', 'count']) + '\n')
 
-            def keyfunc(x): 
+            def keyfunc(x):
                 return x.query_name.split('_', 1)[0]
             for _, g in groupby(samfile, keyfunc):
                 gene_umi_dict = defaultdict(lambda: defaultdict(int))
@@ -265,22 +311,6 @@ class Count(Step):
         df_sum = df_sum.sort_values(col, ascending=False)
         return df_sum
 
-    '''
-    @utils.add_log
-    def plot_barcode_UMI(df_sum, threshold, expected_cell_num, cell_num, outdir, sample, cell_calling_method, col='UMI'):
-        out_plot = f'{outdir}/{sample}_barcode_UMI_plot.pdf'
-        import matplotlib
-        import matplotlib.pyplot as plt
-        fig = plt.figure()
-        plt.plot(df_sum['UMI'])
-        plt.hlines(threshold, 0, cell_num, linestyle='dashed')
-        plt.vlines(cell_num, 0, threshold, linestyle='dashed')
-        plt.title('cell_calling_method: %s, expected_cell_num: %s\n %s threshold: %s, cell num: %s' %
-                (cell_calling_method, expected_cell_num, col, threshold, cell_num))
-        plt.loglog()
-        plt.savefig(out_plot)
-    '''
-
     def get_cell_stats(self, df_sum, cell_bc):
         df_sum.loc[:, 'mark'] = 'UB'
         df_sum.loc[df_sum.index.isin(cell_bc), 'mark'] = 'CB'
@@ -294,7 +324,7 @@ class Count(Step):
             os.mkdir(matrix_dir)
 
         df_UMI = df.groupby(['geneID', 'Barcode']).agg({'UMI': 'count'})
-        mtx = coo_matrix((df_UMI.UMI, (df_UMI.index.labels[0], df_UMI.index.labels[1])))
+        mtx = coo_matrix((df_UMI.UMI, (df_UMI.index.codes[0], df_UMI.index.codes[1])))
         gene_id = df_UMI.index.levels[0].to_series()
         # add gene symbol
         gene_name = gene_id.apply(lambda x: self.id_name[x])
@@ -303,7 +333,7 @@ class Count(Step):
 
         barcodes = df_UMI.index.levels[1].to_series()
         genes.to_csv(f'{matrix_dir}/{FEATURE_FILE_NAME}', index=False, sep='\t', header=False)
-        barcodes.to_csv(f'{matrix_dir}/{BARCODE_FILE_NAME}', index=False, sep='\t')
+        barcodes.to_csv(f'{matrix_dir}/{BARCODE_FILE_NAME}', index=False, sep='\t', header=False)
         mmwrite(f'{matrix_dir}/{MATRIX_FILE_NAME}', mtx)
 
     @utils.add_log
@@ -396,7 +426,7 @@ class Count(Step):
         """saturation and median gene
         return fraction=1 saturation
         """
-        cell_read_index = np.array(df_cell.index.repeat(df_cell['count']))
+        cell_read_index = np.array(df_cell.index.repeat(df_cell['count']), dtype='int32')
         np.random.shuffle(cell_read_index)
 
         format_str = "%.2f\t%.2f\t%.2f\n"
@@ -430,12 +460,44 @@ def count(args):
 
 
 def get_opts_count(parser, sub_program):
+    parser.add_argument('--genomeDir', help='Required. Genome directory.')
+    parser.add_argument('--expected_cell_num', help='Default `3000`. Expected cell number.', default=3000)
+    parser.add_argument(
+        '--cell_calling_method',
+        help='Default `auto`. Cell calling methods. Choose from `auto`, `cellranger3` and `inflection`.',
+        choices=['auto', 'cellranger3', 'inflection', ],
+        default='auto',
+    )
     if sub_program:
         parser = s_common(parser)
-        parser.add_argument('--bam', required=True)
-        parser.add_argument('--force_cell_num', help='force cell number', default=None)
-    parser.add_argument('--genomeDir', help='genome directory')
-    parser.add_argument('--gtf', help='gtf file path')
-    parser.add_argument('--expected_cell_num', help='expected cell number', default=3000)
-    parser.add_argument('--cell_calling_method', help='cell calling methods',
-                        choices=['auto', 'cellranger3', 'inflection', ], default='auto')
+        parser.add_argument('--bam', help='Required. BAM file from featureCounts.', required=True)
+        parser.add_argument(
+            '--force_cell_num',
+            help='Default `None`. Force the cell number within (value * 0.9, value * 1.1). ',
+        )
+
+
+class Count_test(unittest.TestCase):
+    def test_correct_umi(self):
+        dic = {
+            "apple1": 2,
+            "apple2": 30,
+            "bears1": 5,
+            "bears2": 10,
+            "bears3": 100,
+            "ccccc1": 20,
+            "ccccc2": 199,
+        }
+        n_corrected_umi, n_corrected_read = Count.correct_umi(dic)
+        dic_after_correct = {
+            'ccccc1': 20,
+            'apple2': 32,
+            'bears3': 115,
+            'ccccc2': 199,
+        }
+        self.assertEqual(dic, dic_after_correct)
+        self.assertEqual(n_corrected_umi, 3)
+        self.assertEqual(n_corrected_read, 2 + 5 + 10)
+
+if __name__ == "__main__":
+    unittest.main()
\ No newline at end of file
