@@ -1,6 +1,7 @@
 
 import numpy as np
 import pysam
+import sys
 
 import celescope.tools.utils as utils
 from celescope.tools.step import Step, s_common
@@ -24,14 +25,28 @@ class Target_metrics(Step):
         Step.__init__(self, args, step_name)
 
         # set
-        self.match_barcode, _num = utils.read_barcode_file(args.match_dir)
-        self.gene_list, self.n_gene = utils.read_one_col(args.gene_list)
-        self.count_dict = utils.genDict(dim=3, valType=int)
+        self.match_barcode, self.n_cell = utils.read_barcode_file(args.match_dir)
+        self.match_barcode = set(self.match_barcode)
         
+        if (self.assay == "snp" and args.panel != '') :
+            self.gene_list = utils.get_gene_region_from_bed(args.panel)[0]
+            self.n_gene = len(self.gene_list)
+        else:
+            self.gene_list, self.n_gene = utils.read_one_col(args.gene_list)
+
+        if not self.gene_list:
+            sys.exit("You must provide either --panel or --gene_list!")            
+        
+        self.count_dict = utils.genDict(dim=3, valType=int)
+
         self.add_metric(
             name="Number of Target Genes",
             value=self.n_gene,
         )
+        self.add_metric(
+            name="Number of Cells",
+            value=self.n_cell,
+        )
 
         # out file
         self.out_bam_file = f'{self.out_prefix}_filtered.bam'
@@ -75,8 +90,20 @@ class Target_metrics(Step):
                         cell_enriched_read += gene_read
             if barcode in self.match_barcode:
                 enriched_reads_per_cell_list.append(cell_enriched_read)
+
+        if self.debug:
+            self.parse_count_dict_add_metrics.logger.debug(
+                f'enriched_reads_per_cell_list: '
+                f'{sorted(enriched_reads_per_cell_list)}'
+                f'len: {len(enriched_reads_per_cell_list)}'
+            )
         
-        
+        n_valid_cell = len([cell for cell in enriched_reads_per_cell_list if cell > 0])
+        self.add_metric(
+            name="Number of Valid Cells",
+            value=n_valid_cell,
+            total=self.n_cell,
+        )        
         self.add_metric(
             name="Enriched Reads",
             value=enriched_reads,
@@ -88,7 +115,7 @@ class Target_metrics(Step):
             total=total_reads,
         )
         self.add_metric(
-            name="Median Enriched Reads per Cell",
+            name="Median Enriched Reads per Valid Cell",
             value=np.median(enriched_reads_per_cell_list),
         )
 
@@ -112,7 +139,8 @@ def target_metrics(args):
 
 
 def get_opts_target_metrics(parser, sub_program):
-    parser.add_argument("--gene_list", help=HELP_DICT['gene_list'], required=True)
+    parser.add_argument("--gene_list", help=HELP_DICT['gene_list'])
+    parser.add_argument("--panel",help = "The prefix of bed file, such as `lung_1`.",default = '')
     if sub_program:
         parser.add_argument("--bam", help='Input bam file', required=True)
         parser.add_argument('--match_dir', help=HELP_DICT['match_dir'], required=True)
