@@ -21,6 +21,7 @@ import xopen
 
 import celescope.tools
 from celescope.tools.__init__ import __PATTERN_DICT__
+from celescope.__init__ import ROOT_PATH
 from celescope.capture_virus.otsu import array2hist, makePlot, threshold_otsu
 
 tools_dir = os.path.dirname(celescope.tools.__file__)
@@ -324,6 +325,20 @@ def read_one_col(file):
     num = len(col1)
     return col1, num
 
+def get_gene_region_from_bed(panel):
+    """
+    Returns 
+    - genes
+    - position_df with 'Chromosome', 'Start', 'End'
+    """
+    file_path = f'{ROOT_PATH}/data/snp/panel/{panel}.bed'
+    bed_file_df = pd.read_table(file_path, 
+                                usecols=[0,1,2,3],
+                                names=['Chromosome', 'Start', 'End','Gene'],
+                                sep = "\t")
+    position_df = bed_file_df.loc[:,['Chromosome', 'Start', 'End']]
+    genes = set(bed_file_df.loc[:,'Gene'].to_list())
+    return genes, position_df
 
 def read_fasta(fasta_file, equal=False):
     # seq must have equal length
